%{!?build_mpi:%define build_mpi 1}

Name:           paraview
Version:        3.0.2
Release:        2%{?dist}
Summary:        Parallel visualization application

Group:          Applications/Engineering
License:        BSD
URL:            http://www.paraview.org/
# This version was actually made with:
#  cvs -d :pserver:anoncvs@www.paraview.org:/cvsroot/ParaView3 login
#          (respond with empty password)
#  cvs -d :pserver:anoncvs@www.paraview.org:/cvsroot/ParaView3 -z3 export -r ParaView_3_0_2 ParaView3
#  mv ParaView3 paraview-3.0.2
#  tar czf paraview-3.0.2.tar.gz paraview-3.0.2
#
# Next release promises to provide a source tarball
Source0:        http://www.paraview.org/files/v3.0/paraview-%{version}.tar.gz
Source1:        paraview_22x22.png
Source2:        paraview.xml
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  cmake
%if %{build_mpi}
BuildRequires:  openmpi-devel
%endif
BuildRequires:  qt4-devel, mesa-libOSMesa-devel
BuildRequires:  python-devel, tk-devel, hdf5-devel
BuildRequires:  freetype-devel, libtiff-devel, zlib-devel
BuildRequires:  expat-devel
BuildRequires:  /usr/bin/desktop-file-install
BuildRequires:  doxygen, graphviz
Requires:       %{name}-data = %{version}-%{release}
Requires(post):   /usr/bin/update-desktop-database
Requires(postun): /usr/bin/update-desktop-database


%description
ParaView is an application designed with the need to visualize large data
sets in mind. The goals of the ParaView project include the following:

    * Develop an open-source, multi-platform visualization application.
    * Support distributed computation models to process large data sets.
    * Create an open, flexible, and intuitive user interface.
    * Develop an extensible architecture based on open standards.

ParaView runs on distributed and shared memory parallel as well as single
processor systems and has been successfully tested on Windows, Linux and
various Unix workstations and clusters. Under the hood, ParaView uses the
Visualization Toolkit as the data processing and rendering engine and has a
user interface written using a unique blend of Tcl/Tk and C++.

NOTE: This version has NOT been compiled with MPI support.


%if %{build_mpi}
%package        mpi
Summary:        Parallel visualization application
Group:          Applications/Engineering
Requires:       %{name}-data = %{version}-%{release}
Provides:       %{name}
Requires(post):   /usr/bin/update-desktop-database
Requires(postun): /usr/bin/update-desktop-database

%description    mpi
ParaView is an application designed with the need to visualize large data
sets in mind. The goals of the ParaView project include the following:

    * Develop an open-source, multi-platform visualization application.
    * Support distributed computation models to process large data sets.
    * Create an open, flexible, and intuitive user interface.
    * Develop an extensible architecture based on open standards.

ParaView runs on distributed and shared memory parallel as well as single
processor systems and has been successfully tested on Windows, Linux and
various Unix workstations and clusters. Under the hood, ParaView uses the
Visualization Toolkit as the data processing and rendering engine and has a
user interface written using a unique blend of Tcl/Tk and C++.

NOTE: This version has been compiled with OpenMPI support and requires an
operating OpenMPI runtime enviroment.
%endif

%package        data
Summary:        Data files for ParaView
Group:          Applications/Engineering
Requires:       %{name} = %{version}-%{release}
Requires(post):   /usr/bin/update-mime-database
Requires(postun): /usr/bin/update-mime-database

%description    data
%{summary}.


%package        devel
Summary:        Development files for ParaView
Group:          Applications/Engineering
Requires:       %{name} = %{version}-%{release}

%description    devel
%{summary}.


%package        mpi-devel
Summary:        Development files for the mpi version of ParaView
Group:          Applications/Engineering
Requires:       %{name}-mpi = %{version}-%{release}

%description    mpi-devel
%{summary}.


%prep
%setup -q
rm -rf Utilities/TclTk


%build
rm -rf fedora fedora-mpi
mkdir fedora
pushd fedora
export CC='gcc'
export CXX='g++'
export MAKE='make'
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"
%cmake .. \
        -DPV_INSTALL_LIB_DIR:PATH=/%{_lib}/paraview \
        -DCMAKE_CXX_COMPILER:FILEPATH=$CXX \
        -DCMAKE_C_COMPILER:FILEPATH=$CC \
        -DTCL_LIBRARY:PATH=tcl \
        -DTK_LIBRARY:PATH=tk \
        -DPARAVIEW_ENABLE_PYTHON:BOOL=ON \
        -DPARAVIEW_USE_SYSTEM_HDF5:BOOL=ON \
        -DVTK_OPENGL_HAS_OSMESA:BOOL=ON \
	-DVTK_USE_INFOVIS:BOOL=OFF \
        -DVTK_USE_SYSTEM_EXPAT:BOOL=ON \
        -DVTK_USE_SYSTEM_FREETYPE:BOOL=ON \
        -DVTK_USE_SYSTEM_JPEG:BOOL=ON \
        -DVTK_USE_SYSTEM_PNG:BOOL=ON \
        -DVTK_USE_SYSTEM_TIFF:BOOL=ON \
        -DVTK_USE_SYSTEM_ZLIB:BOOL=ON \
        -DBUILD_DOCUMENTATION:BOOL=ON \
        -DBUILD_EXAMPLES:BOOL=ON
cmake ..
make VERBOSE=1 %{?_smp_mflags}
popd
%if %{build_mpi}
mkdir fedora-mpi
pushd fedora-mpi
export CC='gcc'
export CXX='mpic++'
export MAKE='make'
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"
%cmake .. \
        -DPV_INSTALL_LIB_DIR:PATH=/%{_lib}/paraview-mpi \
        -DCMAKE_CXX_COMPILER:FILEPATH=$CXX \
        -DCMAKE_C_COMPILER:FILEPATH=$CC \
        -DTCL_LIBRARY:PATH=tcl \
        -DTK_LIBRARY:PATH=tk \
        -DPARAVIEW_ENABLE_PYTHON:BOOL=ON \
        -DPARAVIEW_USE_SYSTEM_HDF5:BOOL=ON \
        -DICET_BUILD_TESTING:BOOL=ON \
        -DVTK_USE_MPI:BOOL=ON \
        -DMPI_INCLUDE_PATH:PATH="%{_includedir}/openmpi" \
        -DMPI_LIBRARY:STRING="-L%{_libdir}/openmpi" \
        -DVTK_OPENGL_HAS_OSMESA:BOOL=ON \
	-DVTK_USE_INFOVIS:BOOL=OFF \
        -DVTK_USE_SYSTEM_EXPAT:BOOL=ON \
        -DVTK_USE_SYSTEM_FREETYPE:BOOL=ON \
        -DVTK_USE_SYSTEM_JPEG:BOOL=ON \
        -DVTK_USE_SYSTEM_PNG:BOOL=ON \
        -DVTK_USE_SYSTEM_TIFF:BOOL=ON \
        -DVTK_USE_SYSTEM_ZLIB:BOOL=ON \
        -DBUILD_DOCUMENTATION:BOOL=ON \
        -DBUILD_EXAMPLES:BOOL=ON
cmake ..
make VERBOSE=1 %{?_smp_mflags}
%endif

%install
rm -rf $RPM_BUILD_ROOT

#Fix permissions
find . \( -name \*.txt -o -name \*.xml -o -name '*.[ch]' -o -name '*.[ch][px][px]' \) -print0 | xargs -0 chmod -x

# Create some needed directories
install -d $RPM_BUILD_ROOT%{_datadir}/applications
install -d $RPM_BUILD_ROOT%{_datadir}/pixmaps
install -m644 %SOURCE1 $RPM_BUILD_ROOT%{_datadir}/pixmaps
install -d $RPM_BUILD_ROOT%{_datadir}/mime/packages
install -m644 %SOURCE2 $RPM_BUILD_ROOT%{_datadir}/mime/packages

%if %{build_mpi}
# Install mpi version
pushd fedora-mpi
make install DESTDIR=$RPM_BUILD_ROOT

#Create desktop file
cat > paraview-mpi.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=ParaView Viewer MPI
GenericName=Data Viewer
Comment=ParaView allows MPI enabled viewing of large data sets
Type=Application
Terminal=false
Icon=paraview_22x22.png
MimeType=application/x-paraview
Categories=Application;Graphics;
Exec=mpirun C paraview-mpi
EOF

desktop-file-install --vendor=fedora \
       --add-category=X-Fedora \
       --dir %{buildroot}%{_datadir}/applications/ \
       paraview-mpi.desktop

popd

#Move the mpi binaries, includes, and man pages out of the way
pushd $RPM_BUILD_ROOT/%{_bindir}
for f in *
do
   mv $f ${f}-mpi
done
popd
mv $RPM_BUILD_ROOT/%{_includedir}/paraview-3.0 $RPM_BUILD_ROOT/%{_includedir}/paraview-3.0-mpi
rm -rf $RPM_BUILD_ROOT%{_mandir}
%endif

#Install the normal version
pushd fedora
make install DESTDIR=$RPM_BUILD_ROOT

#Create desktop file
cat > paraview.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=ParaView Viewer
GenericName=Data Viewer
Comment=ParaView allows viewing of large data sets
Type=Application
Terminal=false
Icon=paraview_22x22.png
MimeType=application/x-paraview
Categories=Application;Graphics;
Exec=paraview
EOF

desktop-file-install --vendor=fedora \
       --add-category=X-Fedora \
       --dir %{buildroot}%{_datadir}/applications/ \
       paraview.desktop

popd

#Don't ship the VTK Qt Designer plugin
rm -r $RPM_BUILD_ROOT/usr/plugins


%clean
rm -rf $RPM_BUILD_ROOT


%post
update-desktop-database &> /dev/null ||:


%postun
update-desktop-database &> /dev/null ||:


%if %{build_mpi}
%post   mpi
update-desktop-database &> /dev/null ||:

%postun mpi
update-desktop-database &> /dev/null ||:
%endif

%post   data
update-mime-database %{_datadir}/mime &> /dev/null || :

%postun data
update-mime-database %{_datadir}/mime &> /dev/null || :


%files
%defattr(-,root,root,-)
%doc License_v1.1.txt
%{_bindir}/paraview
%{_bindir}/pvdataserver
%{_bindir}/pvpython
%{_bindir}/pvrenderserver
%{_bindir}/pvserver
%{_bindir}/pvTestDriver
%{_bindir}/vtkSMExtractDocumentation
%{_datadir}/applications/fedora-paraview.desktop
%{_libdir}/paraview/


%if %{build_mpi}
%files mpi
%defattr(-,root,root,-)
%doc License_v1.1.txt
%{_bindir}/paraview-mpi
%{_bindir}/pvdataserver-mpi
%{_bindir}/pvpython-mpi
%{_bindir}/pvrenderserver-mpi
%{_bindir}/pvserver-mpi
%{_bindir}/pvTestDriver-mpi
%{_bindir}/vtkSMExtractDocumentation-mpi
%{_datadir}/applications/fedora-paraview-mpi.desktop
%{_libdir}/paraview-mpi/
%endif


%files data
%defattr(-,root,root,-)
%{_datadir}/pixmaps/paraview_22x22.png
%{_datadir}/mime/packages/paraview.xml


%files devel
%defattr(-,root,root,-)
%{_includedir}/paraview-3.0/


%files mpi-devel
%defattr(-,root,root,-)
%{_includedir}/paraview-3.0-mpi/


%changelog
* Thu Aug 23 2007 - Orion Poplawski <orion@cora.wnra.com> - 3.0.2-2
- Update license tag to BSD
- Fix make %%{_smp_mflags}
- Rebuild for ppc32

* Wed Jul 11 2007 - Orion Poplawski <orion@cora.wnra.com> - 3.0.2-1
- Update to 3.0.2
- Turn mpi build back on
- Add devel packages
- Remove demo package no longer in upstream
- Use cmake macros

* Thu Mar 08 2007 - Orion Poplawski <orion@cora.wnra.com> - 2.4.4-6
- Don't build mpi version until upstream fixes the build system

* Fri Dec 22 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.4-5
- Fix .so permissions
- Patch for const issue
- Patch for new cmake
- Build with openmpi

* Thu Dec 14 2006 - Jef Spaleta <jspaleta@gmail.com> - 2.4.4-4
- Bump and build for python 2.5

* Fri Oct  6 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.4-3
- Install needed python libraries to get around make install bug

* Wed Oct  4 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.4-2
- Re-enable OSMESA support for FC6
- Enable python wrapping

* Fri Sep 15 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.4-1
- Update to 2.4.4

* Thu Jun 29 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.3-8
- No OSMesa support in FC5
- Make data sub-package pull in main package (bug #193837)
- A patch from CVS to fix vtkXOpenRenderWindow.cxx
- Need lam-devel for FC6

* Fri Apr 21 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.3-7
- Re-enable ppc

* Mon Apr 17 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.3-6
- Exclude ppc due to gcc bug #189160

* Wed Apr 12 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.3-5
- Cleanup permissions

* Mon Apr 10 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.3-4
- Add icon and cleanup desktop file

* Mon Apr 10 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.3-3
- Add VTK_USE_MANGLE_MESA for off screen rendering
- Cleanup source permisions
- Add an initial .desktop file
- Make requirement on -data specific to version
- Don't package Ice-T man pages and cmake files

* Thu Apr  6 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.3-2
- Add mpi version

* Tue Apr  4 2006 - Orion Poplawski <orion@cora.wnra.com> - 2.4.3-1
- Initial Fedora Extras version
